**********
References
**********

.. _glossary:

Glossary
--------

.. glossary::

    LIRA
      Lira stands for (L)ow-counts (I)mage (R)econstruction and (A)nalysis.

.. _references:

References
----------

This is the bibliography containing the literature references for the implemented methods
referenced from the pylira docs.

.. [Esch2004] `Esch et al. (2004) <https://ui.adsabs.harvard.edu/abs/2004ApJ...610.1213E/>`_,
   "An Image Restoration Technique with Error Estimates",

.. [Connors2007] `Connors et al. (2007) <https://ui.adsabs.harvard.edu/abs/2007ASPC..371..101C>`_,
   "How To Win With Non-Gaussian Data: Poisson Goodness-of-Fit",

.. [Connors2011] `Connors et al. (2011) <https://ui.adsabs.harvard.edu/abs/2011ASPC..442..463C>`_,
   "LIRA — The Low-Counts Image Restoration and Analysis Package: A Teaching Version via R",

.. [Stein2015] `Stein et al. (2015) <https://ui.adsabs.harvard.edu/abs/2015ApJ...813...66S>`_,
   "Detecting Unspecified Structure in Low-count Images",
